# Minus80
[![Build Status](https://travis-ci.org/LinkageIO/Minus80.svg?branch=master)](https://travis-ci.org/LinkageIO/Minus80)
[![Coverage Status](https://coveralls.io/repos/github/LinkageIO/Minus80/badge.svg?branch=master)](https://coveralls.io/github/LinkageIO/Minus80?branch=master)
[![codecov](https://codecov.io/gh/LinkageIO/Minus80/branch/master/graph/badge.svg)](https://codecov.io/gh/LinkageIO/Minus80)

This library is for freezing and integrating data. Modeled after how minus 80°C freezers work.



## Installation

Option 1: Clone the repo manually and run:
```
python setup.py install
```
Option 1: Use pip:
```
pip install git+https://github.com/schae234/Minus80.git
```

## Documentation
http://linkage.io/docs/minus80/
